(v1.11.4)=
### 1.11.4 {small}`2025-07-30`

### Bug fixes

- Recalculate colors when color keys length does not match number of categories e.g., in {func}`scanpy.pl.umap` {smaller}`Ilan G` ({pr}`3725`)
- Use `dask` version from `anndata` for the `[dask]` extra in `scanpy` {smaller}`I Gold` ({pr}`3737`)
- Fix {func}`~scanpy.tl.leiden` with igraph backend on Windows {smaller}`P Angerer` ({pr}`3745`)
- Fix setup of initial log stream {smaller}`P Angerer` ({pr}`3747`)
- Remove upper bound from `scipy` version {smaller}`P Angerer` ({pr}`3752`)

### Documentation

- Update {doc}`/tutorials/basics/clustering-2017` for more compatibility {smaller}`I Gold` ({pr}`3748`)
